@@ -4,13 +4,13 @@ Chartbeat template tags and filters.
 
 from __future__ import absolute_import
 
+import json
 import re
 
 from django.conf import settings
 from django.contrib.sites.models import Site
 from django.core.exceptions import ImproperlyConfigured
 from django.template import Library, Node, TemplateSyntaxError
-from django.utils import simplejson
 
 from analytical.utils import is_internal_ip, disable_html, get_required_setting
 
@@ -86,7 +86,7 @@ class ChartbeatBottomNode(Node):
         domain = _get_domain(context)
         if domain is not None:
             config['domain'] = domain
-        html = SETUP_CODE % {'config': simplejson.dumps(config)}
+        html = SETUP_CODE % {'config': json.dumps(config, sort_keys=True)}
         if is_internal_ip(context, 'CHARTBEAT'):
             html = disable_html(html, 'Chartbeat')
         return html
@@ -100,9 +100,14 @@ def contribute_to_analytical(add_node):
 
 def _get_domain(context):
     domain = context.get(DOMAIN_CONTEXT_KEY)
-    if domain is None and getattr(settings, 'CHARTBEAT_AUTO_DOMAIN', True):
-        try:
-            domain = Site.objects.get_current().domain
-        except (ImproperlyConfigured, Site.DoesNotExist): #pylint: disable=E1101
-            pass
-    return domain
+
+    if domain is not None:
+        return domain
+    else:
+        if 'django.contrib.sites' not in settings.INSTALLED_APPS:
+            return
+        elif getattr(settings, 'CHARTBEAT_AUTO_DOMAIN', True):
+            try:
+                return Site.objects.get_current().domain
+            except (ImproperlyConfigured, Site.DoesNotExist): #pylint: disable=E1101
+                return
