@@ -44,26 +44,21 @@ class WoopraTagTestCase(TagTestCase):
         r = WoopraNode().render(Context({'woopra_var1': 'val1',
                 'woopra_var2': 'val2'}))
         self.assertTrue('var woo_visitor = {"var1": "val1", "var2": "val2"};'
-                in r, r)
+            in r, r)
 
     @override_settings(ANALYTICAL_AUTO_IDENTIFY=True)
     def test_identify_name_and_email(self):
         r = WoopraNode().render(Context({'user': User(username='test',
                 first_name='Firstname', last_name='Lastname',
                 email="test@example.com")}))
-        self.assertTrue('var woo_visitor = {"name": "Firstname Lastname", '
-                '"email": "test@example.com"};' in r, r)
+        self.assertTrue('var woo_visitor = {"email": "test@example.com", '
+                '"name": "Firstname Lastname"};' in r, r)
 
     @override_settings(ANALYTICAL_AUTO_IDENTIFY=True)
     def test_identify_username_no_email(self):
         r = WoopraNode().render(Context({'user': User(username='test')}))
         self.assertTrue('var woo_visitor = {"name": "test"};' in r, r)
 
-    @override_settings(ANALYTICAL_AUTO_IDENTIFY=True)
-    def test_identify_anonymous_user(self):
-        r = WoopraNode().render(Context({'user': AnonymousUser()}))
-        self.assertTrue('var woo_visitor = {};' in r, r)
-
     @override_settings(ANALYTICAL_AUTO_IDENTIFY=True)
     def test_no_identify_when_explicit_name(self):
         r = WoopraNode().render(Context({'woopra_name': 'explicit',
@@ -76,6 +71,11 @@ class WoopraTagTestCase(TagTestCase):
                 'user': User(username='implicit')}))
         self.assertTrue('var woo_visitor = {"email": "explicit"};' in r, r)
 
+    @override_settings(ANALYTICAL_AUTO_IDENTIFY=True)
+    def test_identify_anonymous_user(self):
+        r = WoopraNode().render(Context({'user': AnonymousUser()}))
+        self.assertTrue('var woo_visitor = {};' in r, r)
+
     @override_settings(ANALYTICAL_INTERNAL_IPS=['1.1.1.1'])
     def test_render_internal_ip(self):
         req = HttpRequest()
